# -*- coding: utf-8 -*-
# copyright 2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.

from cubicweb.web import facet
from cubicweb.predicates import is_instance


class ScanTypeFacet(facet.AttributeFacet):
    __regid__ = 'scan-type-facet'
    __select__ = facet.AttributeFacet.__select__ & is_instance('Scan')
    order = 1
    rtype = 'type'
    title = _('Type')

class ScanLabelFacet(facet.AttributeFacet):
    __regid__ = 'scan-label-facet'
    __select__ = facet.AttributeFacet.__select__ & is_instance('Scan')
    order = 1
    rtype = 'label'
    title = _('Has Label')
